@@ -171,7 +171,8 @@ class SiteMgr:
                 maxconcurrent=self.maxConcurrent,
                 Verbosity=self.Verbosity,
                 noInsert=self.noInsert,
-                chkCalcNode=self.chkCalcNode
+                chkCalcNode=self.chkCalcNode,
+                mtype=self.mtype,
                 )
             self.sites.append(site)
     
@@ -831,10 +832,15 @@ class SiteState:
                     rec['name'], rec))
             # precompute the CHK
             name = rec['name']
-            uri = self.chkCalcNode.genchk(
-                data=raw, 
-                mimetype=rec['mimetype'], 
-                TargetFilename=ChkTargetFilename(name))
+            try:
+                uri = self.chkCalcNode.genchk(
+                    data=raw, 
+                    mimetype=rec['mimetype'], 
+                    TargetFilename=ChkTargetFilename(name))
+            except fcp.node.FCPProtocolError: # likely unsupported mime type
+                uri = self.chkCalcNode.genchk(
+                    data=raw, 
+                    TargetFilename=ChkTargetFilename(name))
             rec['uri'] = uri
             rec['state'] = 'waiting'
     
@@ -1564,6 +1570,7 @@ class SiteState:
                     "Files.%d.Name=%s" % (n, rec['name']),
                     "Files.%d.UploadFrom=disk" % n,
                     "Files.%d.Filename=%s" % (n, rec['path']),
+                    "Files.%d.Metadata.ContentType=%s" % (n, rec['mimetype']),
                 ]
             else:
                 if rec['name'] in self.generatedTextData:
@@ -1577,6 +1584,7 @@ class SiteState:
                     "Files.%d.Name=%s" % (n, rec['name']),
                     "Files.%d.UploadFrom=direct" % n,
                     "Files.%d.DataLength=%s" % (n, rec['sizebytes']),
+                    "Files.%d.Metadata.ContentType=%s" % (n, rec['mimetype']),
                 ]
 
             
